@@ -6,16 +6,15 @@ from .verifier import AzureVerifier
 
 class AzureAuth(TokenAuth):
 
-    def validate_token(self, token):
-        tenant = app.configget('AZURE_AD_TENANT')
+    def get_configs(self):
+        tenant = app.config.get('AZURE_AD_TENANT')
         issuer = app.config['AZURE_AD_ISSUER']
         audiences = app.config['AZURE_AD_AUDIENCES']
 
-        try:
-            return AzureVerifier(tenant, issuer, audiences).verify(token)
-        except Exception as e:
-            app.logger.error(e)
-        return False
+        return dict(tenant=tenant, issuer=issuer, audiences=audiences)
+
+    def validate_token(self, token):
+        return AzureVerifier(**self.get_configs()).verify(token)
 
     def check_auth(self, token, allowed_roles, resource, method):
         return self.validate_token(token)
